# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/love/love/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Love\\Love\\": "packages/love/love/src",
            "Love\\Love\\Seeders\\": "packages/love/love/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Love\Love\Providers\LoveServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Love'  => Love\Love\Facades\Love::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Love\\Love\\Seeders\\LoveTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Love\Love\Providers\LoveServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Love\Love\Providers\LoveServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Love\Love\Providers\LoveServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/love/{modulename}

**User**

    http://path-to-route-folder/user/love/{modulename}

**Public**

    http://path-to-route-folder/loves


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/love/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/love/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/love/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/love/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/love/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/love/{modulename}/{slug}
    METHOD: GET